# ISO_LATIN_1 tables from:
# https://www.ime.usp.br/~pf/algoritmos/apend/iso-latin-1.html
const ENCODE_ISO_LATIN_1 = Dict{Char, UInt8}(
    ' ' => 0xA0, # non-breaking space
    '¡' => 0xA1, # exclamação invertida
    '¢' => 0xA2, # 
    '£' => 0xA3, # libra
    '¤' => 0xA4, # moeda genérica
    '¥' => 0xA5, # yen
    '¦' => 0xA6, # 
    '§' => 0xA7, # parágrafo
    '¨' => 0xA8, # trema
    '©' => 0xA9, # copyright
    'ª' => 0xAA, # ordinal feminino
    '«' => 0xAB, # abre-aspas europeu
    '¬' => 0xAC, # negação lógica
    '­'  => 0xAD, # soft hyphen
    '®' => 0xAE, # registrado
    '¯' => 0xAF, # overscore
    '°' => 0xB0, # grau
    '±' => 0xB1, # mais ou menos
    '²' => 0xB2, # ao quadrado
    '³' => 0xB3, # ao cubo
    '´' => 0xB4, # acento agudo
    'µ' => 0xB5, # micro, mü
    '¶' => 0xB6, # parágrafo
    '·' => 0xB7, # middle dot
    '¸' => 0xB8, # cedilha
    '¹' => 0xB9, # elevado a 1
    'º' => 0xBA, # ordinal masculino
    '»' => 0xBB, # fecha-aspas europeu
    '¼' => 0xBC, # 
    '½' => 0xBD, # 
    '¾' => 0xBE, # 
    '¿' => 0xBF, # interrogação invertida
    'À' => 0xC0, # 
    'Á' => 0xC1, # 
    'Â' => 0xC2, # 
    'Ã' => 0xC3, # 
    'Ä' => 0xC4, # 
    'Å' => 0xC5, # 
    'Æ' => 0xC6, # ligadura AE
    'Ç' => 0xC7, # 
    'È' => 0xC8, # 
    'É' => 0xC9, # 
    'Ê' => 0xCA, # 
    'Ë' => 0xCB, # 
    'Ì' => 0xCC, # 
    'Í' => 0xCD, # 
    'Î' => 0xCE, # 
    'Ï' => 0xCF, # 
    'Ð' => 0xD0, # Eth (islândico)
    'Ñ' => 0xD1, # 
    'Ò' => 0xD2, # 
    'Ó' => 0xD3, # 
    'Ô' => 0xD4, # 
    'Õ' => 0xD5, # 
    'Ö' => 0xD6, # 
    '×' => 0xD7, # multiplicação
    'Ø' => 0xD8, # 
    'Ù' => 0xD9, # 
    'Ú' => 0xDA, # 
    'Û' => 0xDB, # 
    'Ü' => 0xDC, # 
    'Ý' => 0xDD, # 
    'Þ' => 0xDE, # Thorn (islândico)
    'ß' => 0xDF, # ligadura sz (alemão)
    'à' => 0xE0, # 
    'á' => 0xE1, # 
    'â' => 0xE2, # 
    'ã' => 0xE3, # 
    'ä' => 0xE4, # 
    'å' => 0xE5, # 
    'æ' => 0xE6, # ligadura ae
    'ç' => 0xE7, # 
    'è' => 0xE8, # 
    'é' => 0xE0, # 
    'ê' => 0xEA, # 
    'ë' => 0xEB, # 
    'ì' => 0xEC, # 
    'í' => 0xED, # 
    'î' => 0xEE, # 
    'ï' => 0xEF, # 
    'ð' => 0xF0, # eth (islândico)
    'ñ' => 0xF1, # 
    'ò' => 0xF2, # 
    'ó' => 0xF3, # 
    'ô' => 0xF4, # 
    'õ' => 0xF5, # 
    'ö' => 0xF6, # 
    '÷' => 0xF7, # divisão
    'ø' => 0xF8, # 
    'ù' => 0xF9, # 
    'ú' => 0xFA, # 
    'û' => 0xFB, # 
    'ü' => 0xFC, # 
    'ý' => 0xFD, # 
    'þ' => 0xFE, # thorn (islândico)
    'ÿ' => 0xFF, # 
)

const DECODE_ISO_LATIN_1 = Dict{UInt8, Char}(
    0xA0 => ' ', # non-breaking space
    0xA1 => '¡', # exclamação invertida
    0xA2 => '¢', # 
    0xA3 => '£', # libra
    0xA4 => '¤', # moeda genérica
    0xA5 => '¥', # yen
    0xA6 => '¦', # 
    0xA7 => '§', # parágrafo
    0xA8 => '¨', # trema
    0xA9 => '©', # copyright
    0xAA => 'ª', # ordinal feminino
    0xAB => '«', # abre-aspas europeu
    0xAC => '¬', # negação lógica
    0xAD => '­' , # soft hyphen
    0xAE => '®', # registrado
    0xAF => '¯', # overscore
    0xB0 => '°', # grau
    0xB1 => '±', # mais ou menos
    0xB2 => '²', # ao quadrado
    0xB3 => '³', # ao cubo
    0xB4 => '´', # acento agudo
    0xB5 => 'µ', # micro, mü
    0xB6 => '¶', # parágrafo
    0xB7 => '·', # middle dot
    0xB8 => '¸', # cedilha
    0xB9 => '¹', # elevado a 1
    0xBA => 'º', # ordinal masculino
    0xBB => '»', # fecha-aspas europeu
    0xBC => '¼', # 
    0xBD => '½', # 
    0xBE => '¾', # 
    0xBF => '¿', # interrogação invertida
    0xC0 => 'À', # 
    0xC1 => 'Á', # 
    0xC2 => 'Â', # 
    0xC3 => 'Ã', # 
    0xC4 => 'Ä', # 
    0xC5 => 'Å', # 
    0xC6 => 'Æ', # ligadura AE
    0xC7 => 'Ç', # 
    0xC8 => 'È', # 
    0xC9 => 'É', # 
    0xCA => 'Ê', # 
    0xCB => 'Ë', # 
    0xCC => 'Ì', # 
    0xCD => 'Í', # 
    0xCE => 'Î', # 
    0xCF => 'Ï', # 
    0xD0 => 'Ð', # Eth (islândico)
    0xD1 => 'Ñ', # 
    0xD2 => 'Ò', # 
    0xD3 => 'Ó', # 
    0xD4 => 'Ô', # 
    0xD5 => 'Õ', # 
    0xD6 => 'Ö', # 
    0xD7 => '×', # multiplicação
    0xD8 => 'Ø', # 
    0xD9 => 'Ù', # 
    0xDA => 'Ú', # 
    0xDB => 'Û', # 
    0xDC => 'Ü', # 
    0xDD => 'Ý', # 
    0xDE => 'Þ', # Thorn (islândico)
    0xDF => 'ß', # ligadura sz (alemão)
    0xE0 => 'à', # 
    0xE1 => 'á', # 
    0xE2 => 'â', # 
    0xE3 => 'ã', # 
    0xE4 => 'ä', # 
    0xE5 => 'å', # 
    0xE6 => 'æ', # ligadura ae
    0xE7 => 'ç', # 
    0xE8 => 'è', # 
    0xE0 => 'é', # 
    0xEA => 'ê', # 
    0xEB => 'ë', # 
    0xEC => 'ì', # 
    0xED => 'í', # 
    0xEE => 'î', # 
    0xEF => 'ï', # 
    0xF0 => 'ð', # eth (islândico)
    0xF1 => 'ñ', # 
    0xF2 => 'ò', # 
    0xF3 => 'ó', # 
    0xF4 => 'ô', # 
    0xF5 => 'õ', # 
    0xF6 => 'ö', # 
    0xF7 => '÷', # divisão
    0xF8 => 'ø', # 
    0xF9 => 'ù', # 
    0xFA => 'ú', # 
    0xFB => 'û', # 
    0xFC => 'ü', # 
    0xFD => 'ý', # 
    0xFE => 'þ', # thorn (islândico)
    0xFF => 'ÿ', # 
)